vsnInputPara:
Class to contain input data and parameters for parallel vsn functions
Description
Class extends the class vsnInput. The class contains input data and parameters for parallel vsn functions.
Creating Objects
new("vsnInputPara")Slots
...:- as class
vsnInput. dimAB:- The dimension of the complete AffyBatch.
Methods
dim- Get dimensions of data matrix.
nrow- Get number of rows of data matrix.
ncol- Get number of columns of data matrix.